// Copyright (c) 2014,2015 Walter Bender
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// You should have received a copy of the GNU General Public License
// along with this library; if not, write to the Free Software
// Foundation, 51 Franklin Street, Suite 500 Boston, MA 02110-1335 USA
// Munsell data converted to sRGB
//
// Munsell data derived from CPAN Color::Model::Munsell
// http://search.cpan.org/~tonodera/Color-Model-Munsell-0.02/
// which is a vast improvement over the Munsell Perl module 
// written by Walter Bender and Jon Orwant back in the day.

function getMunsellColor(hue, value, chroma) {
    // hue (aka color) 0-100 -> 0-39
    // value (aka shade) 0-100 -> 0-10
    // chroma (aka grey) 0-100 -> 0-14
    // We linear-interpret value.
    var h = Math.round(hue / 2.5);
    h %= 40; // doesn't guarentee it will be positive.
    while (h < 0) {
        h += 40;
    }
    var v1 = Math.floor(value / 10);
    var v2 = v1 + 1;
    if (v1 < 0) {
        v1 = 0;
        v2 = 0;
    } else if (v1 > 10) {
        v1 = 10;
        v2 = 10;
    }
    var p = (v2 * 10 - value) / 10.;
    if (p > 1) {
        p = 1;
    } else if (p < 0) {
        p = 0;
    }
    var c = Math.round((chroma * 14) / 100);
    if (c < 0) {
        c = 0;
    } else if (c > 14) {
        c = 14;
    }
    return interpColor(MUNSELL[h * 165 + v1 * 15 + c], MUNSELL[h * 165 + v2 * 15 + c], p);
}


interpColor = function(hex1, hex2, p) {
    if (p == 0) {
        return hex2;
    } else if (p == 1) {
        return hex1;
    } else {
        var r1 = parseInt(hex1.substr(1, 2), 16);
        var g1 = parseInt(hex1.substr(3, 2), 16);
        var b1 = parseInt(hex1.substr(5, 2), 16);
        var r2 = parseInt(hex2.substr(1, 2), 16);
        var g2 = parseInt(hex2.substr(3, 2), 16);
        var b2 = parseInt(hex2.substr(5, 2), 16);

        var nr = Math.floor(r1 * p + r2 * (1 - p));
        var ng = Math.floor(g1 * p + g2 * (1 - p));
        var nb = Math.floor(b1 * p + b2 * (1 - p));

        return createjs.Graphics.getRGB(nr, ng, nb, 1.0);
    }
};


function getcolor(color) {
    var h1 = Math.floor(color / 2.5);
    var h2 = h1 + 1;
    p = h2 - (color / 2.5);

    h1 %= 40; // doesn't guarentee it will be positive.
    while (h1 < 0) {
        h1 += 40;
    }

    h2 = h1 + 1;
    if (h2 == 40) {
        h2 = 0;
    }

    var v = Math.floor(COLORS40[h1][0] * p + COLORS40[h2][0] * (1 - p));
    var c = Math.floor(COLORS40[h1][1] * p + COLORS40[h2][1] * (1 - p));
    return [v * 10., c * 100. / 14, interpColor(COLORS40[h1][2], COLORS40[h2][2], p)];
}


// Searches for nearest match to high chroma colors, scaled from 0-100
function searchColors(r, g, b) {
    var nearestColor = -1;
    var distance = 10000000;
    for (i = 0; i < 100; i++) {
	var color = getcolor(i);
        var r1 = parseInt(color[2].substr(1, 2), 16);
        var g1 = parseInt(color[2].substr(3, 2), 16);
        var b1 = parseInt(color[2].substr(5, 2), 16);
	var distSquared = (r1 - r) * (r1 - r) + (g1 - g) * (g1 - g) + (b1 - b) * (b1 - b);
	if (distSquared < distance) {
	    distance = distSquared;
	    nearestColor = i;
	}
    }
    return nearestColor;
}


// 40 high-chroma colors [value, chroma, RGB]
COLORS40 = [
    [6, 24, "#ff007e"],
    [6, 24, "#ff0066"],
    [6, 24, "#ff0048"],
    [6, 26, "#ff0000"],
    [6, 26, "#ff3000"],
    [6, 20, "#fd6600"],
    [8, 24, "#ffa300"],
    [8, 22, "#ffb000"],
    [8, 22, "#ffb900"],
    [8, 22, "#ffc000"],
    [9, 22, "#ffe400"],
    [9, 22, "#ffe800"],
    [9, 22, "#f6ee00"],
    [9, 22, "#e1f400"],
    [9, 22, "#c4fb00"],
    [8, 28, "#4eeb00"],
    [8, 22, "#00f200"],
    [8, 28, "#00fd3c"],
    [6, 28, "#00c260"],
    [6, 28, "#00c273"],
    [6, 28, "#00c286"],
    [6, 28, "#00c29d"],
    [6, 26, "#00c1b6"],
    [6, 24, "#00c0ca"],
    [6, 24, "#00c0e7"],
    [6, 20, "#00b9f1"],
    [6, 20, "#00b5ff"],
    [6, 20, "#00b0ff"],
    [6, 20, "#00abff"],
    [6, 18, "#00a1ff"],
    [4, 28, "#005dff"],
    [4, 28, "#4231ff"],
    [4, 28, "#8000fe"],
    [4, 28, "#a000ef"],
    [6, 28, "#f009ff"],
    [6, 28, "#ff00ff"],
    [6, 28, "#ff00f9"],
    [6, 28, "#ff00d9"],
    [6, 26, "#ff00b2"],
    [6, 24, "#ff0098"]
];


// 10RP 2.5R 5R 7.5R 10R ... 7.5RP -> V0 - V10 -> C0 - C28 (by 2)
MUNSELL = [
    // 10RP (0R)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2c1620", "#350f23", "#3d0526", "#450029", "#4c002c", "#530030", "#5a0034", "#600037", "#600037", "#600037", "#600037", "#600037", "#600037", "#600037",
    "#313131", "#412c32", "#4c2633", "#561e34", "#601136", "#690038", "#73003b", "#7c003d", "#850040", "#8d0043", "#8d0043", "#8d0043", "#8d0043", "#8d0043", "#8d0043",
    "#484848", "#5b4247", "#693c45", "#753444", "#802843", "#8b1843", "#960043", "#9f0043", "#aa0044", "#b30044", "#bc0046", "#bc0046", "#bc0046", "#bc0046", "#bc0046",
    "#616161", "#735c5f", "#82565d", "#8f4e5b", "#9b4659", "#a63c58", "#b12e57", "#bc1756", "#c60056", "#d10056", "#db0056", "#e30057", "#ed0058", "#ed0058", "#ed0058",
    "#7a7a7a", "#8b7679", "#9b7076", "#a96973", "#b76171", "#c3596f", "#d04d6d", "#da416c", "#e62d6b", "#f0036a", "#fc0069", "#ff0069", "#ff0068", "#ff0068", "#ff0068",
    "#949494", "#a59193", "#b58b8f", "#c4848c", "#d17e8a", "#de7587", "#eb6c85", "#f76183", "#ff5281", "#ff417f", "#ff277f", "#ff007e", "#ff007e", "#ff007e", "#ff007e",
    "#aeaeae", "#beabad", "#cfa6aa", "#df9fa6", "#ee98a3", "#fc90a0", "#ff869d", "#ff7b9a", "#ff6e98", "#ff6095", "#ff5293", "#ff5293", "#ff5293", "#ff5293", "#ff5293",
    "#c8c8c8", "#d7c7c8", "#eac0c4", "#fbbac0", "#ffb2bc", "#ffa9b9", "#ff9db5", "#ff94b1", "#ff94b1", "#ff94b1", "#ff94b1", "#ff94b1", "#ff94b1", "#ff94b1", "#ff94b1",
    "#c8c8c8", "#d7c7c8", "#eac0c4", "#fbbac0", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc", "#ffb2bc",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5R
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2d161e", "#360f1f", "#3f0321", "#470023", "#4e0025", "#570028", "#570028", "#570028", "#570028", "#570028", "#570028", "#570028", "#570028", "#570028",
    "#313131", "#422c30", "#4d262f", "#571e2f", "#620f2f", "#6c002f", "#760030", "#800031", "#890032", "#890032", "#890032", "#890032", "#890032", "#890032", "#890032",
    "#484848", "#5c4244", "#6a3c41", "#76343d", "#82283a", "#8d1738", "#980036", "#a10034", "#ab0033", "#b50032", "#c10032", "#c10032", "#c10032", "#c10032", "#c10032",
    "#616161", "#745c5d", "#835659", "#904e55", "#9d4651", "#a83c4e", "#b32e4b", "#be1548", "#c80046", "#d30044", "#dd0041", "#e60041", "#ef003e", "#ef003e", "#ef003e",
    "#7a7a7a", "#8c7677", "#9c7072", "#ab696d", "#b86169", "#c55864", "#d24c60", "#dc415d", "#e82d5a", "#f30057", "#ff0055", "#ff0054", "#ff0053", "#ff0052", "#ff0051",
    "#949494", "#a59191", "#b68b8c", "#c68486", "#d37d81", "#e1757d", "#ee6b78", "#f96174", "#ff5270", "#ff416c", "#ff2a69", "#ff0067", "#ff0066", "#ff0066", "#ff0066",
    "#aeaeae", "#bfabab", "#d0a5a6", "#e09fa0", "#f0989b", "#fe9095", "#ff868f", "#ff7b8b", "#ff6e86", "#ff6282", "#ff6282", "#ff6282", "#ff6282", "#ff6282", "#ff6282",
    "#c8c8c8", "#d8c7c7", "#ecc0c0", "#fdb9ba", "#ffb1b3", "#ffa9ad", "#ff9ea6", "#ff9ea6", "#ff9ea6", "#ff9ea6", "#ff9ea6", "#ff9ea6", "#ff9ea6", "#ff9ea6", "#ff9ea6",
    "#c8c8c8", "#d8c7c7", "#ecc0c0", "#fdb9ba", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3", "#ffb1b3",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5R
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2e161c", "#370f1b", "#40021c", "#48001c", "#50001d", "#59001f", "#59001f", "#59001f", "#59001f", "#59001f", "#59001f", "#59001f", "#59001f", "#59001f",
    "#313131", "#422c2e", "#4e262b", "#581d29", "#630e26", "#6e0025", "#770024", "#810024", "#8b0024", "#8b0024", "#8b0024", "#8b0024", "#8b0024", "#8b0024", "#8b0024",
    "#484848", "#5c4342", "#6b3c3c", "#763437", "#822a31", "#8d192c", "#980028", "#a10025", "#ab0021", "#b6001f", "#c1001e", "#c1001e", "#c1001e", "#c1001e", "#c1001e",
    "#616161", "#745c5b", "#845554", "#914f4d", "#9e4647", "#a93c41", "#b3303b", "#be1a34", "#c8002f", "#d30029", "#dc0025", "#e40021", "#ed001d", "#ed001d", "#ed001d",
    "#7a7a7a", "#8c7675", "#9d706e", "#ac6966", "#ba625f", "#c65858", "#d34d51", "#dd424b", "#e92f44", "#f4083e", "#fd0039", "#ff0034", "#ff0031", "#ff0031", "#ff0031",
    "#949494", "#a6918f", "#b78b88", "#c78480", "#d47d79", "#e27572", "#ef6c6b", "#fb6264", "#ff545c", "#ff4455", "#ff3150", "#ff0a4b", "#ff0048", "#ff0048", "#ff0048",
    "#aeaeae", "#c0abaa", "#d2a5a2", "#e29f9a", "#f29892", "#ff908b", "#ff8682", "#ff7c7b", "#ff7073", "#ff646d", "#ff646d", "#ff646d", "#ff646d", "#ff646d", "#ff646d",
    "#c8c8c8", "#d9c7c5", "#edc0bc", "#ffb9b3", "#ffb1aa", "#ffa9a2", "#ff9e98", "#ff9e98", "#ff9e98", "#ff9e98", "#ff9e98", "#ff9e98", "#ff9e98", "#ff9e98", "#ff9e98",
    "#e3e3e3", "#f4e2e0", "#ffdbd5", "#ffd3cb", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4", "#ffcbc4",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5R
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2e161a", "#380f18", "#410216", "#490016", "#510016", "#5a0016", "#5a0016", "#5a0016", "#5a0016", "#5a0016", "#5a0016", "#5a0016", "#5a0016", "#5a0016",
    "#313131", "#432c2c", "#4f2627", "#591e22", "#63111d", "#6e0019", "#770016", "#810014", "#8b0012", "#8b0012", "#8b0012", "#8b0012", "#8b0012", "#8b0012", "#8b0012",
    "#484848", "#5c4340", "#6a3c38", "#763530", "#812b28", "#8c1d1f", "#970017", "#a00010", "#a90008", "#b40000", "#c00000", "#c00000", "#c00000", "#c00000", "#c00000",
    "#616161", "#745c59", "#845650", "#914f47", "#9e473e", "#a83e35", "#b2332c", "#bc2222", "#c60018", "#cf000b", "#d90000", "#e00000", "#ea0000", "#ea0000", "#ea0000",
    "#7a7a7a", "#8d7673", "#9e706a", "#ac6a60", "#ba6256", "#c65a4b", "#d25041", "#dc4537", "#e7362b", "#f0201f", "#f90010", "#ff0000", "#ff0000", "#ff0000", "#ff0000",
    "#949494", "#a7908d", "#b88b83", "#c7857a", "#d57e6f", "#e37664", "#ef6e5a", "#fa644e", "#ff5942", "#ff4c34", "#ff3e29", "#ff2914", "#ff0d00", "#ff0000", "#ff0000",
    "#aeaeae", "#c1aba7", "#d3a59d", "#e39f93", "#f39887", "#ff917d", "#ff8871", "#ff7f65", "#ff7558", "#ff6b4f", "#ff6045", "#ff6045", "#ff6045", "#ff6045", "#ff6045",
    "#c8c8c8", "#d9c7c3", "#efc0b7", "#ffb9ab", "#ffb29f", "#ffaa93", "#ffa185", "#ff987c", "#ff987c", "#ff987c", "#ff987c", "#ff987c", "#ff987c", "#ff987c", "#ff987c",
    "#e3e3e3", "#f5e2de", "#ffdad0", "#ffd4c2", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7", "#ffccb7",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10R (0YR)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2e1717", "#390e13", "#410310", "#4a000d", "#52000b", "#5a000a", "#5a000a", "#5a000a", "#5a000a", "#5a000a", "#5a000a", "#5a000a", "#5a000a", "#5a000a",
    "#313131", "#422d2a", "#4e2622", "#581f1b", "#631313", "#6c000b", "#760004", "#800000", "#890000", "#890000", "#890000", "#890000", "#890000", "#890000", "#890000",
    "#484848", "#5c433e", "#6a3d34", "#75362a", "#802e1f", "#8a2212", "#930e00", "#9c0000", "#a50000", "#ae0000", "#b80000", "#b80000", "#b80000", "#b80000", "#b80000",
    "#616161", "#755c57", "#84564b", "#905040", "#9c4933", "#a64125", "#af3913", "#b72e00", "#be2200", "#c60600", "#cc0000", "#d40000", "#db0000", "#db0000", "#db0000",
    "#7a7a7a", "#8d7771", "#9e7164", "#ac6b57", "#b96449", "#c55d3a", "#cf5529", "#d74d14", "#df4500", "#e63a00", "#ee2c00", "#f51400", "#fc0000", "#ff0000", "#ff0000",
    "#949494", "#a8918a", "#b98b7d", "#c78671", "#d47f63", "#e17854", "#ec7144", "#f76931", "#ff6216", "#ff5900", "#ff4f00", "#ff4500", "#ff3b00", "#ff3000", "#ff3000",
    "#aeaeae", "#c1aba5", "#d3a697", "#e3a08a", "#f29a7b", "#fe936e", "#ff8c5c", "#ff844a", "#ff7c33", "#ff761d", "#ff6e00", "#ff6e00", "#ff6e00", "#ff6e00", "#ff6e00",
    "#c8c8c8", "#dac7c1", "#f0c0b1", "#ffbaa2", "#ffb493", "#ffad84", "#ffa572", "#ff9e61", "#ff9e61", "#ff9e61", "#ff9e61", "#ff9e61", "#ff9e61", "#ff9e61", "#ff9e61",
    "#e3e3e3", "#f6e2db", "#ffdbc9", "#ffd5ba", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab", "#ffcdab",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 25 YR
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2e1714", "#390f0b", "#410505", "#490000", "#520000", "#520000", "#520000", "#520000", "#520000", "#520000", "#520000", "#520000", "#520000", "#520000",
    "#313131", "#422d28", "#4e271e", "#572112", "#611801", "#690700", "#690700", "#690700", "#690700", "#690700", "#690700", "#690700", "#690700", "#690700", "#690700",
    "#484848", "#5b443c", "#683e2f", "#723921", "#7b330f", "#822d00", "#8a2400", "#8a2400", "#8a2400", "#8a2400", "#8a2400", "#8a2400", "#8a2400", "#8a2400", "#8a2400",
    "#616161", "#745d54", "#835746", "#8e5238", "#984d27", "#a04711", "#a64300", "#ac3d00", "#ac3d00", "#ac3d00", "#ac3d00", "#ac3d00", "#ac3d00", "#ac3d00", "#ac3d00",
    "#7a7a7a", "#8d776e", "#9c725f", "#aa6c50", "#b6673e", "#c0612b", "#c75c11", "#cd5800", "#d15500", "#d65000", "#d65000", "#d65000", "#d65000", "#d65000", "#d65000",
    "#949494", "#a89187", "#b78c78", "#c68768", "#d28259", "#dd7c46", "#e67730", "#ee720d", "#f46e00", "#f86a00", "#fd6600", "#fd6600", "#fd6600", "#fd6600", "#fd6600",
    "#aeaeae", "#c2aba2", "#d2a792", "#e2a181", "#ef9c71", "#fa9760", "#ff914a", "#ff8b2d", "#ff8700", "#ff8300", "#ff8000", "#ff8000", "#ff8000", "#ff8000", "#ff8000",
    "#c8c8c8", "#dbc7bd", "#efc1aa", "#febc9a", "#ffb687", "#ffb175", "#ffab60", "#ffa548", "#ffa548", "#ffa548", "#ffa548", "#ffa548", "#ffa548", "#ffa548", "#ffa548",
    "#e3e3e3", "#f7e2d8", "#ffdcc3", "#ffd7b0", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d", "#ffd09d",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5YR
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2d1810", "#381101", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00", "#3f0a00",
    "#313131", "#412e26", "#4b2918", "#542404", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00", "#5c1e00",
    "#484848", "#5a443a", "#65402b", "#6e3c19", "#753800", "#7b3400", "#7b3400", "#7b3400", "#7b3400", "#7b3400", "#7b3400", "#7b3400", "#7b3400", "#7b3400", "#7b3400",
    "#616161", "#735d51", "#815940", "#8a5530", "#93511c", "#994d00", "#9e4a00", "#a34600", "#a34600", "#a34600", "#a34600", "#a34600", "#a34600", "#a34600", "#a34600",
    "#7a7a7a", "#8c776b", "#9a735a", "#a76f47", "#b16a33", "#b8661b", "#be6300", "#c36100", "#c75e00", "#c75e00", "#c75e00", "#c75e00", "#c75e00", "#c75e00", "#c75e00",
    "#949494", "#a79184", "#b58d73", "#c28960", "#cd854c", "#d68136", "#de7d17", "#e37a00", "#e77800", "#ea7600", "#ed7400", "#ed7400", "#ed7400", "#ed7400", "#ed7400",
    "#aeaeae", "#c2ac9e", "#d1a88c", "#dea479", "#e9a066", "#f39b50", "#fd9735", "#ff9404", "#ff9100", "#ff8f00", "#ff8e00", "#ff8c00", "#ff8c00", "#ff8c00", "#ff8c00",
    "#c8c8c8", "#dbc7b9", "#ecc3a5", "#fabe92", "#ffba7c", "#ffb667", "#ffb24e", "#ffae2e", "#ffaa00", "#ffa800", "#ffa600", "#ffa500", "#ffa300", "#ffa300", "#ffa300",
    "#e3e3e3", "#f7e2d3", "#ffdebc", "#ffd9a8", "#ffd593", "#ffd07e", "#ffd07e", "#ffd07e", "#ffd07e", "#ffd07e", "#ffd07e", "#ffd07e", "#ffd07e", "#ffd07e", "#ffd07e",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5YR
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2b190d", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400", "#351400",
    "#313131", "#3f2f24", "#482b12", "#502800", "#552500", "#552500", "#552500", "#552500", "#552500", "#552500", "#552500", "#552500", "#552500", "#552500", "#552500",
    "#484848", "#584538", "#624227", "#6a3f12", "#6f3c00", "#743a00", "#743a00", "#743a00", "#743a00", "#743a00", "#743a00", "#743a00", "#743a00", "#743a00", "#743a00",
    "#616161", "#725e4f", "#7e5a3b", "#865729", "#8d550f", "#925200", "#955100", "#955100", "#955100", "#955100", "#955100", "#955100", "#955100", "#955100", "#955100",
    "#7a7a7a", "#8b7869", "#987455", "#a37140", "#ab6e28", "#b16c03", "#b56a00", "#b86800", "#bb6700", "#bb6700", "#bb6700", "#bb6700", "#bb6700", "#bb6700", "#bb6700",
    "#949494", "#a69282", "#b38f6e", "#be8b59", "#c88842", "#cf8526", "#d48300", "#d88100", "#db8000", "#dd7f00", "#dd7f00", "#dd7f00", "#dd7f00", "#dd7f00", "#dd7f00",
    "#aeaeae", "#c0ad9b", "#cea987", "#daa672", "#e4a35c", "#eca043", "#f39d1f", "#f89b00", "#fc9900", "#fe9800", "#ff9800", "#ff9800", "#ff9800", "#ff9800", "#ff9800",
    "#c8c8c8", "#dbc8b5", "#e9c4a0", "#f6c18b", "#ffbd73", "#ffbb5b", "#ffb83e", "#ffb509", "#ffb300", "#ffb200", "#ffb100", "#ffb000", "#ffb000", "#ffb000", "#ffb000",
    "#e3e3e3", "#f7e3cf", "#ffdfb7", "#ffdca0", "#ffd989", "#ffd671", "#ffd359", "#ffd359", "#ffd359", "#ffd359", "#ffd359", "#ffd359", "#ffd359", "#ffd359", "#ffd359",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10YR (0Y)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#291a0a", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600", "#321600",
    "#313131", "#3d2f22", "#452d0e", "#4c2b00", "#502900", "#502900", "#502900", "#502900", "#502900", "#502900", "#502900", "#502900", "#502900", "#502900", "#502900",
    "#484848", "#564636", "#5e4423", "#654209", "#694000", "#6e3e00", "#6e3e00", "#6e3e00", "#6e3e00", "#6e3e00", "#6e3e00", "#6e3e00", "#6e3e00", "#6e3e00", "#6e3e00",
    "#616161", "#705f4c", "#7a5c37", "#815a22", "#865800", "#8a5700", "#8d5600", "#8d5600", "#8d5600", "#8d5600", "#8d5600", "#8d5600", "#8d5600", "#8d5600", "#8d5600",
    "#7a7a7a", "#897966", "#947650", "#9e7438", "#a4721c", "#a87000", "#ab6f00", "#ae6e00", "#b06d00", "#b06d00", "#b06d00", "#b06d00", "#b06d00", "#b06d00", "#b06d00",
    "#949494", "#a4937f", "#af9169", "#b98e51", "#c08c38", "#c68a13", "#ca8900", "#cd8800", "#cf8700", "#d18600", "#d18600", "#d18600", "#d18600", "#d18600", "#d18600",
    "#aeaeae", "#beae98", "#caab81", "#d4a96a", "#dca752", "#e3a535", "#e9a300", "#eda100", "#efa100", "#f1a000", "#f2a000", "#f2a000", "#f2a000", "#f2a000", "#f2a000",
    "#c8c8c8", "#d9c8b2", "#e5c69b", "#efc483", "#f9c269", "#ffc04f", "#ffbe2b", "#ffbc00", "#ffbb00", "#ffba00", "#ffb900", "#ffb900", "#ffb900", "#ffb900", "#ffb900",
    "#e3e3e3", "#f5e4cb", "#ffe2b1", "#ffdf99", "#ffdd7f", "#ffdb63", "#ffd948", "#ffd948", "#ffd948", "#ffd948", "#ffd948", "#ffd948", "#ffd948", "#ffd948", "#ffd948",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5Y
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#271b08", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900", "#2e1900",
    "#313131", "#3b3121", "#422f08", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00", "#472d00",
    "#484848", "#534735", "#5a4620", "#604401", "#644300", "#644300", "#644300", "#644300", "#644300", "#644300", "#644300", "#644300", "#644300", "#644300", "#644300",
    "#616161", "#6d604b", "#755f34", "#7b5d1b", "#7f5c00", "#825b00", "#845b00", "#845b00", "#845b00", "#845b00", "#845b00", "#845b00", "#845b00", "#845b00", "#845b00",
    "#7a7a7a", "#877a64", "#90784c", "#977731", "#9c7610", "#9f7500", "#a27400", "#a47300", "#a47300", "#a47300", "#a47300", "#a47300", "#a47300", "#a47300", "#a47300",
    "#949494", "#a1947c", "#aa9365", "#b2914b", "#b8902e", "#bd8f00", "#c08e00", "#c28d00", "#c48d00", "#c48d00", "#c48d00", "#c48d00", "#c48d00", "#c48d00", "#c48d00",
    "#aeaeae", "#bbaf96", "#c5ad7d", "#ceac64", "#d4aa49", "#daa926", "#dea800", "#e1a700", "#e3a700", "#e4a600", "#e5a600", "#e5a600", "#e5a600", "#e5a600", "#e5a600",
    "#c8c8c8", "#d6caaf", "#e0c897", "#e8c77d", "#f0c662", "#f6c444", "#fbc312", "#ffc200", "#ffc100", "#ffc100", "#ffc000", "#ffc000", "#ffc000", "#ffc000", "#ffc000",
    "#e3e3e3", "#f2e5c8", "#fce4ad", "#ffe393", "#ffe178", "#ffe05c", "#ffdf37", "#ffdf37", "#ffdf37", "#ffdf37", "#ffdf37", "#ffdf37", "#ffdf37", "#ffdf37", "#ffdf37",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5Y
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#241c08", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00", "#2a1b00",
    "#313131", "#393120", "#3e3005", "#423000", "#423000", "#423000", "#423000", "#423000", "#423000", "#423000", "#423000", "#423000", "#423000", "#423000", "#423000",
    "#484848", "#504835", "#56481e", "#5a4700", "#5d4600", "#5d4600", "#5d4600", "#5d4600", "#5d4600", "#5d4600", "#5d4600", "#5d4600", "#5d4600", "#5d4600", "#5d4600",
    "#616161", "#6a614a", "#706131", "#756016", "#785f00", "#7a5f00", "#7b5f00", "#7b5f00", "#7b5f00", "#7b5f00", "#7b5f00", "#7b5f00", "#7b5f00", "#7b5f00", "#7b5f00",
    "#7a7a7a", "#837b63", "#8a7b49", "#907a2d", "#947902", "#967900", "#987800", "#9a7800", "#9a7800", "#9a7800", "#9a7800", "#9a7800", "#9a7800", "#9a7800", "#9a7800",
    "#949494", "#9e957b", "#a49562", "#ab9446", "#af9425", "#b29300", "#b59300", "#b69200", "#b89200", "#b89200", "#b89200", "#b89200", "#b89200", "#b89200", "#b89200",
    "#aeaeae", "#b8b094", "#bfb07a", "#c5af5f", "#caaf43", "#ceae14", "#d1ad00", "#d3ad00", "#d4ad00", "#d5ad00", "#d5ad00", "#d5ad00", "#d5ad00", "#d5ad00", "#d5ad00",
    "#c8c8c8", "#d3cbad", "#d9cb93", "#dfca78", "#e5ca5b", "#e9c938", "#edc900", "#efc800", "#f1c800", "#f2c800", "#f3c800", "#f3c800", "#f3c800", "#f3c800", "#f3c800",
    "#e3e3e3", "#efe6c6", "#f5e6aa", "#fbe68f", "#ffe672", "#ffe552", "#ffe522", "#ffe500", "#ffe400", "#ffe400", "#ffe400", "#ffe400", "#ffe400", "#ffe400", "#ffe400",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5Y
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#221d0a", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00", "#261d00",
    "#313131", "#363221", "#3a3204", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200", "#3d3200",
    "#484848", "#4e4935", "#51491e", "#544900", "#564900", "#564900", "#564900", "#564900", "#564900", "#564900", "#564900", "#564900", "#564900", "#564900", "#564900",
    "#616161", "#67624a", "#6b6231", "#6e6213", "#706200", "#726200", "#736200", "#736200", "#736200", "#736200", "#736200", "#736200", "#736200", "#736200", "#736200",
    "#7a7a7a", "#817c63", "#867c49", "#897c2a", "#8b7c00", "#8d7c00", "#8e7c00", "#8f7c00", "#8f7c00", "#8f7c00", "#8f7c00", "#8f7c00", "#8f7c00", "#8f7c00", "#8f7c00",
    "#949494", "#9b967b", "#a09761", "#a49744", "#a79720", "#a99700", "#aa9700", "#ab9700", "#ac9600", "#ac9600", "#ac9600", "#ac9600", "#ac9600", "#ac9600", "#ac9600",
    "#aeaeae", "#b6b194", "#bab179", "#beb25e", "#c1b23f", "#c4b205", "#c6b200", "#c7b200", "#c8b200", "#c8b200", "#c8b200", "#c8b200", "#c8b200", "#c8b200", "#c8b200",
    "#c8c8c8", "#d1ccac", "#d5cc92", "#d9cd76", "#dccd58", "#dfcd33", "#e2cd00", "#e3cd00", "#e4cd00", "#e5cd00", "#e6cd00", "#e6cd00", "#e6cd00", "#e6cd00", "#e6cd00",
    "#e3e3e3", "#ece7c5", "#f1e8a9", "#f5e88d", "#f8e96f", "#fbe94e", "#fee915", "#ffe900", "#ffe900", "#ffe900", "#ffe900", "#ffe800", "#ffe800", "#ffe800", "#ffe800",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10Y (0GY)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#1f1e0d", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00", "#201f00",
    "#313131", "#343322", "#353406", "#363400", "#363400", "#363400", "#363400", "#363400", "#363400", "#363400", "#363400", "#363400", "#363400", "#363400", "#363400",
    "#484848", "#4b4a35", "#4d4b1e", "#4e4b00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00", "#4f4c00",
    "#616161", "#64634b", "#666431", "#686513", "#686500", "#696500", "#696500", "#696500", "#696500", "#696500", "#696500", "#696500", "#696500", "#696500", "#696500",
    "#7a7a7a", "#7e7d63", "#807e49", "#827f2b", "#837f00", "#847f00", "#848000", "#858000", "#858000", "#858000", "#858000", "#858000", "#858000", "#858000", "#858000",
    "#949494", "#98977b", "#9b9862", "#9d9945", "#9e9a20", "#9f9a00", "#a09a00", "#a09a00", "#a19a00", "#a19a00", "#a19a00", "#a19a00", "#a19a00", "#a19a00", "#a19a00",
    "#aeaeae", "#b3b294", "#b6b37a", "#b8b45f", "#b9b43f", "#bbb500", "#bbb500", "#bcb500", "#bcb600", "#bcb600", "#bcb600", "#bcb600", "#bcb600", "#bcb600", "#bcb600",
    "#c8c8c8", "#ceccac", "#d1ce92", "#d3cf76", "#d5cf58", "#d6d032", "#d7d100", "#d8d100", "#d8d100", "#d8d100", "#d9d100", "#d9d100", "#d9d100", "#d9d100", "#d9d100",
    "#e3e3e3", "#eae8c5", "#ece9a9", "#efea8d", "#f1eb6e", "#f2ec4d", "#f3ec0f", "#f4ed00", "#f5ed00", "#f5ed00", "#f5ed00", "#f6ee00", "#f6ee00", "#f6ee00", "#f6ee00",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 25GY
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#1c1f10", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100", "#192100",
    "#313131", "#313424", "#2f350d", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700", "#2d3700",
    "#484848", "#484b37", "#474c21", "#454e00", "#434f00", "#434f00", "#434f00", "#434f00", "#434f00", "#434f00", "#434f00", "#434f00", "#434f00", "#434f00", "#434f00",
    "#616161", "#60644d", "#606634", "#5e6719", "#5d6800", "#5c6900", "#5a6900", "#5a6900", "#5a6900", "#5a6900", "#5a6900", "#5a6900", "#5a6900", "#5a6900", "#5a6900",
    "#7a7a7a", "#7a7e65", "#7a804d", "#798131", "#788204", "#778300", "#768400", "#748400", "#748400", "#748400", "#748400", "#748400", "#748400", "#748400", "#748400",
    "#949494", "#95987c", "#949a64", "#939c49", "#929d26", "#919e00", "#919f00", "#909f00", "#909f00", "#909f00", "#909f00", "#909f00", "#909f00", "#909f00", "#909f00",
    "#aeaeae", "#b0b295", "#afb57c", "#aeb663", "#adb844", "#acb911", "#acba00", "#abba00", "#abbb00", "#aabb00", "#aabb00", "#aabb00", "#aabb00", "#aabb00", "#aabb00",
    "#c8c8c8", "#cbcdad", "#cacf94", "#cad17a", "#c9d35d", "#c8d438", "#c7d500", "#c6d600", "#c6d600", "#c6d700", "#c5d700", "#c5d700", "#c5d700", "#c5d700", "#c5d700",
    "#e3e3e3", "#e7e9c6", "#e6ebaa", "#e6ed8f", "#e5ef71", "#e4f051", "#e3f117", "#e2f200", "#e1f300", "#e1f300", "#e1f300", "#e1f400", "#e1f400", "#e1f400", "#e1f400",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5GY
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#1a1f12", "#112200", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300", "#0a2300",
    "#313131", "#2f3426", "#2a3614", "#233800", "#1c3a00", "#133c00", "#133c00", "#133c00", "#133c00", "#133c00", "#133c00", "#133c00", "#133c00", "#133c00", "#133c00",
    "#484848", "#454b39", "#404e26", "#3c500c", "#375100", "#315300", "#2b5400", "#2b5400", "#2b5400", "#2b5400", "#2b5400", "#2b5400", "#2b5400", "#2b5400", "#2b5400",
    "#616161", "#5e654f", "#596739", "#556922", "#506b00", "#4c6c00", "#4a6d00", "#466e00", "#466e00", "#466e00", "#466e00", "#466e00", "#466e00", "#466e00", "#466e00",
    "#7a7a7a", "#777e67", "#748152", "#6f8439", "#6a8519", "#678700", "#638800", "#618900", "#5e8a00", "#5e8a00", "#5e8a00", "#5e8a00", "#5e8a00", "#5e8a00", "#5e8a00",
    "#949494", "#91997e", "#8e9b68", "#8a9e51", "#85a033", "#81a200", "#7da300", "#7ba400", "#7aa400", "#79a500", "#79a500", "#79a500", "#79a500", "#79a500", "#79a500",
    "#aeaeae", "#acb397", "#a8b680", "#a5b969", "#a1bb4f", "#9cbd29", "#98be00", "#95c000", "#93c000", "#92c100", "#90c100", "#90c100", "#90c100", "#90c100", "#90c100",
    "#c8c8c8", "#c8ceaf", "#c5d197", "#c1d37f", "#bcd665", "#b8d846", "#b4da08", "#b1db00", "#aedc00", "#acdd00", "#abdd00", "#aade00", "#aade00", "#aade00", "#aade00",
    "#e3e3e3", "#e3eac7", "#e0edad", "#dcef93", "#d8f277", "#d5f459", "#d0f62d", "#cdf700", "#c9f900", "#c7fa00", "#c6fa00", "#c4fb00", "#c4fb00", "#c4fb00", "#c4fb00",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5GY
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#172015", "#072304", "#002500", "#002700", "#002700", "#002700", "#002700", "#002700", "#002700", "#002700", "#002700", "#002700", "#002700", "#002700",
    "#313131", "#2c3429", "#23371b", "#163a09", "#003c00", "#003e00", "#004000", "#004100", "#004100", "#004100", "#004100", "#004100", "#004100", "#004100", "#004100",
    "#484848", "#414c3d", "#384f2d", "#2e521c", "#215400", "#065600", "#005800", "#005a00", "#005a00", "#005a00", "#005a00", "#005a00", "#005a00", "#005a00", "#005a00",
    "#616161", "#596553", "#506941", "#466c2f", "#3a6e15", "#2c7100", "#177300", "#007400", "#007600", "#007800", "#007800", "#007800", "#007800", "#007800", "#007800",
    "#7a7a7a", "#737f6b", "#6a835a", "#618646", "#568931", "#4b8b0e", "#3d8d00", "#2f8f00", "#209000", "#069100", "#009300", "#009300", "#009300", "#009300", "#009300",
    "#949494", "#8c9a82", "#849d70", "#7ba15d", "#71a447", "#66a62d", "#5ba900", "#4fab00", "#45ac00", "#3cad00", "#33ae00", "#27af00", "#27af00", "#27af00", "#27af00",
    "#aeaeae", "#a6b59b", "#9eb889", "#96bc76", "#8cbf61", "#82c248", "#77c428", "#6cc600", "#63c800", "#5ac900", "#54ca00", "#4ccb00", "#45cc00", "#45cc00", "#45cc00",
    "#c8c8c8", "#c1d0b4", "#b8d4a0", "#afd78c", "#a7da77", "#9ddd5f", "#93e042", "#88e20a", "#7ee400", "#74e600", "#6ee700", "#65e800", "#5ee900", "#57ea00", "#4eeb00",
    "#e3e3e3", "#dcebcc", "#d3f0b7", "#c9f3a0", "#c0f78a", "#b6fa71", "#adfd55", "#a2ff30", "#97ff00", "#8dff00", "#84ff00", "#7aff00", "#7aff00", "#7aff00", "#7aff00",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10GY (0G)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#152017", "#00230c", "#002602", "#002900", "#002900", "#002900", "#002900", "#002900", "#002900", "#002900", "#002900", "#002900", "#002900", "#002900",
    "#313131", "#2a352b", "#1c3821", "#063b16", "#003d09", "#003f00", "#004100", "#004300", "#004300", "#004300", "#004300", "#004300", "#004300", "#004300", "#004300",
    "#484848", "#3f4d3f", "#315033", "#215327", "#005619", "#005806", "#005a00", "#005c00", "#005c00", "#005c00", "#005c00", "#005c00", "#005c00", "#005c00", "#005c00",
    "#616161", "#576656", "#496a48", "#396d3a", "#23702a", "#007317", "#007600", "#007800", "#007900", "#007b00", "#007b00", "#007b00", "#007b00", "#007b00", "#007b00",
    "#7a7a7a", "#6f806e", "#638461", "#558852", "#438b42", "#2b8e31", "#009119", "#009300", "#009500", "#009700", "#009900", "#009900", "#009900", "#009900", "#009900",
    "#949494", "#889b86", "#7c9f78", "#6ea369", "#5ea659", "#4ba949", "#30ac36", "#00af1a", "#00b100", "#00b400", "#00b600", "#00b700", "#00b700", "#00b700", "#00b700",
    "#aeaeae", "#a2b59f", "#95ba90", "#89bd82", "#7ac172", "#69c561", "#53c84f", "#35cb3a", "#00ce1b", "#00d000", "#00d200", "#00d400", "#00d600", "#00d600", "#00d600",
    "#c8c8c8", "#bcd1b8", "#afd5a8", "#a1d998", "#93dd89", "#82e178", "#6fe465", "#57e751", "#32ea39", "#00ed0c", "#00ef00", "#00f200", "#00f200", "#00f200", "#00f200",
    "#e3e3e3", "#d6edd1", "#c8f1c0", "#b8f6ad", "#aafa9d", "#99fe8b", "#87ff79", "#71ff65", "#52ff4d", "#19ff2e", "#00ff00", "#00ff00", "#00ff00", "#00ff00", "#00ff00",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5G
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#132019", "#002412", "#00270c", "#002a07", "#002a07", "#002a07", "#002a07", "#002a07", "#002a07", "#002a07", "#002a07", "#002a07", "#002a07", "#002a07",
    "#313131", "#28352d", "#163927", "#003c21", "#003e1c", "#004016", "#004211", "#00440e", "#00440e", "#00440e", "#00440e", "#00440e", "#00440e", "#00440e", "#00440e",
    "#484848", "#3c4d42", "#2a513a", "#085434", "#00572e", "#005928", "#005c22", "#005d1d", "#005d1d", "#005d1d", "#005d1d", "#005d1d", "#005d1d", "#005d1d", "#005d1d",
    "#616161", "#536659", "#416b51", "#256f48", "#007241", "#007539", "#007832", "#007a2c", "#007c27", "#007d22", "#007d22", "#007d22", "#007d22", "#007d22", "#007d22",
    "#7a7a7a", "#6c8172", "#5b8569", "#468960", "#238d57", "#00904f", "#009347", "#00963f", "#009838", "#009b31", "#009d2b", "#009d2b", "#009d2b", "#009d2b", "#009d2b",
    "#949494", "#849b8a", "#73a081", "#5fa477", "#46a86e", "#18ab65", "#00af5c", "#00b253", "#00b44b", "#00b743", "#00b93b", "#00bc34", "#00bc34", "#00bc34", "#00bc34",
    "#aeaeae", "#9eb6a4", "#8dbb9a", "#7bbf90", "#64c385", "#45c77b", "#00cb72", "#00ce68", "#00d15f", "#00d356", "#00d64d", "#00d944", "#00db3c", "#00db3c", "#00db3c",
    "#c8c8c8", "#b7d1bd", "#a6d6b2", "#92dba7", "#7ddf9d", "#63e392", "#38e787", "#00ea7e", "#00ee73", "#00f168", "#00f35e", "#00f655", "#00f84c", "#00fa45", "#00fd3c",
    "#e3e3e3", "#d1edd7", "#bff3cb", "#a8f8bd", "#92fdb2", "#78ffa7", "#57ff9c", "#00ff91", "#00ff85", "#00ff78", "#00ff78", "#00ff78", "#00ff78", "#00ff78", "#00ff78",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5G
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#12201a", "#002416", "#002713", "#002a11", "#002b10", "#002b10", "#002b10", "#002b10", "#002b10", "#002b10", "#002b10", "#002b10", "#002b10", "#002b10",
    "#313131", "#27352e", "#12392a", "#003c27", "#003e24", "#004022", "#004220", "#00441f", "#00451e", "#00471e", "#00471e", "#00471e", "#00471e", "#00471e", "#00471e",
    "#484848", "#3b4d44", "#25513f", "#00553a", "#005737", "#005a34", "#005c32", "#005e31", "#005f2f", "#00602e", "#00622e", "#00632d", "#00642c", "#00642c", "#00642c",
    "#616161", "#52675c", "#3c6b56", "#196f50", "#00734c", "#007649", "#007946", "#007b43", "#007c42", "#007e40", "#007f3f", "#00803e", "#00823e", "#00833d", "#00843c",
    "#7a7a7a", "#6a8175", "#56856e", "#3c8a69", "#008e64", "#00915f", "#00945b", "#009759", "#009956", "#009b54", "#009d52", "#009f51", "#00a050", "#00a24f", "#00a34e",
    "#949494", "#829b8e", "#6da187", "#56a581", "#33a97c", "#00ac77", "#00b073", "#00b36f", "#00b56c", "#00b869", "#00ba67", "#00bc65", "#00be63", "#00c061", "#00c260",
    "#aeaeae", "#9cb6a7", "#88bba0", "#72c09a", "#55c494", "#1dc88f", "#00cc8a", "#00cf85", "#00d282", "#00d57f", "#00d87c", "#00da79", "#00dc77", "#00de76", "#00e074",
    "#c8c8c8", "#b5d2c1", "#a1d7ba", "#88dcb2", "#6de0ac", "#45e4a6", "#00e8a1", "#00ec9c", "#00ef98", "#00f294", "#00f591", "#00f88e", "#00fa8c", "#00fa8c", "#00fa8c",
    "#e3e3e3", "#cfeddb", "#b9f3d3", "#9df9cb", "#80fec4", "#5bffbe", "#00ffb8", "#00ffb3", "#00ffae", "#00ffae", "#00ffae", "#00ffae", "#00ffae", "#00ffae", "#00ffae",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5G
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#11201b", "#002419", "#002718", "#002a17", "#002b17", "#002b17", "#002b17", "#002b17", "#002b17", "#002b17", "#002b17", "#002b17", "#002b17", "#002b17",
    "#313131", "#263530", "#0e392d", "#003c2b", "#003e2a", "#004029", "#004228", "#004428", "#004528", "#004728", "#004728", "#004728", "#004728", "#004728", "#004728",
    "#484848", "#3a4d46", "#215142", "#005540", "#00573e", "#005a3d", "#005c3c", "#005e3b", "#005f3b", "#00613a", "#00623a", "#00633a", "#00643a", "#00643a", "#00643a",
    "#616161", "#51675e", "#396b5a", "#096f57", "#007354", "#007652", "#007951", "#007b50", "#007c4f", "#007e4e", "#007f4e", "#00804d", "#00824d", "#00834d", "#00844d",
    "#7a7a7a", "#698177", "#538672", "#368a6f", "#008e6c", "#009169", "#009567", "#009766", "#009964", "#009c63", "#009d62", "#009f61", "#00a061", "#00a260", "#00a360",
    "#949494", "#819b90", "#6aa18b", "#50a588", "#25a984", "#00ac81", "#00b07e", "#00b37c", "#00b67a", "#00b879", "#00bb77", "#00bd76", "#00bf75", "#00c074", "#00c273",
    "#aeaeae", "#9ab6aa", "#85bba5", "#6dc0a1", "#4cc49d", "#00c899", "#00cc96", "#00d093", "#00d391", "#00d58f", "#00d88d", "#00da8c", "#00dc8a", "#00de8a", "#00e088",
    "#c8c8c8", "#b3d2c4", "#9ed7be", "#83dcb9", "#65e0b5", "#32e5b1", "#00e9ae", "#00ecab", "#00efa8", "#00f3a5", "#00f5a3", "#00f8a2", "#00fba0", "#00fba0", "#00fba0",
    "#e3e3e3", "#cdeede", "#b5f4d8", "#97f9d2", "#76fecd", "#4affc9", "#00ffc5", "#00ffc2", "#00ffc2", "#00ffc2", "#00ffc2", "#00ffc2", "#00ffc2", "#00ffc2", "#00ffc2",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10G (0BG)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#10201c", "#00241c", "#00271c", "#002a1e", "#002c20", "#002c20", "#002c20", "#002c20", "#002c20", "#002c20", "#002c20", "#002c20", "#002c20", "#002c20",
    "#313131", "#253531", "#083930", "#003c30", "#003e30", "#004130", "#004330", "#004431", "#004532", "#004733", "#004733", "#004733", "#004733", "#004733", "#004733",
    "#484848", "#384d47", "#1c5246", "#005545", "#005845", "#005a44", "#005c45", "#005e45", "#006045", "#006146", "#006246", "#006347", "#006548", "#006548", "#006548",
    "#616161", "#4f675f", "#356b5e", "#006f5c", "#00735b", "#00765b", "#00795b", "#007b5a", "#007c5b", "#007e5b", "#00805b", "#00815b", "#00825c", "#00835c", "#00845d",
    "#7a7a7a", "#688179", "#508677", "#308a75", "#008e73", "#009172", "#009571", "#009771", "#009a71", "#009c71", "#009d71", "#009f71", "#00a171", "#00a271", "#00a371",
    "#949494", "#809b92", "#67a190", "#4ba58e", "#10a98c", "#00ad8a", "#00b089", "#00b388", "#00b687", "#00b887", "#00bb86", "#00bd86", "#00bf86", "#00c086", "#00c286",
    "#aeaeae", "#99b6ac", "#83bba9", "#68c0a7", "#42c4a5", "#00c8a3", "#00cca1", "#00d0a0", "#00d39f", "#00d59e", "#00d89e", "#00db9d", "#00dc9d", "#00de9c", "#00e09c",
    "#c8c8c8", "#b3d2c6", "#9bd7c3", "#7fdcc0", "#5ee0be", "#1ae5bc", "#00e9ba", "#00ecb9", "#00f0b7", "#00f3b6", "#00f6b5", "#00f8b5", "#00fcb4", "#00fcb4", "#00fcb4",
    "#e3e3e3", "#cceee1", "#b3f4dd", "#93f9da", "#6dfed7", "#37ffd5", "#00ffd3", "#00ffd2", "#00ffd2", "#00ffd2", "#00ffd2", "#00ffd2", "#00ffd2", "#00ffd2", "#00ffd2",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5BG
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#0e201e", "#002420", "#002723", "#002a25", "#002c28", "#002c28", "#002c28", "#002c28", "#002c28", "#002c28", "#002c28", "#002c28", "#002c28", "#002c28",
    "#313131", "#243533", "#043934", "#003c35", "#003e37", "#004138", "#00433a", "#00443b", "#00463d", "#00463d", "#00463d", "#00463d", "#00463d", "#00463d", "#00463d",
    "#484848", "#384d49", "#18524a", "#00554b", "#00584c", "#005a4e", "#005c4f", "#005e51", "#006052", "#006153", "#006254", "#006355", "#006355", "#006355", "#006355",
    "#616161", "#4e6762", "#326b62", "#006f63", "#007364", "#007665", "#007967", "#007b68", "#007d69", "#007e6a", "#00806b", "#00816c", "#00826d", "#00836e", "#00836e",
    "#7a7a7a", "#67817b", "#4e867b", "#2b8a7b", "#008e7b", "#00917c", "#00957e", "#00977f", "#009a80", "#009c82", "#009e83", "#009f84", "#00a185", "#00a286", "#00a386",
    "#949494", "#7f9b94", "#65a194", "#47a594", "#00a994", "#00ad95", "#00b095", "#00b396", "#00b697", "#00b998", "#00bb99", "#00bd9b", "#00bf9c", "#00c19d", "#00c29d",
    "#aeaeae", "#99b6ae", "#81bbad", "#65c0ad", "#38c4ad", "#00c8ad", "#00ccad", "#00d0ae", "#00d2af", "#00d5b0", "#00d8b1", "#00dab1", "#00dcb2", "#00deb3", "#00deb3",
    "#c8c8c8", "#b2d1c8", "#99d7c7", "#7ddcc6", "#57e0c6", "#00e5c6", "#00e9c6", "#00ecc6", "#00efc7", "#00f3c8", "#00f6c8", "#00f6c8", "#00f6c8", "#00f6c8", "#00f6c8",
    "#e3e3e3", "#cbede3", "#b1f3e2", "#8ff9e1", "#66fee0", "#19ffdf", "#00ffdf", "#00ffdf", "#00ffdf", "#00ffdf", "#00ffdf", "#00ffdf", "#00ffdf", "#00ffdf", "#00ffdf",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5BG
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#0c2020", "#002425", "#00272a", "#002a2f", "#002a2f", "#002a2f", "#002a2f", "#002a2f", "#002a2f", "#002a2f", "#002a2f", "#002a2f", "#002a2f", "#002a2f",
    "#313131", "#233535", "#003938", "#003c3c", "#003e40", "#004143", "#004346", "#004449", "#00464c", "#00464c", "#00464c", "#00464c", "#00464c", "#00464c", "#00464c",
    "#484848", "#364d4c", "#13514f", "#005553", "#005756", "#005a5a", "#005c5d", "#005e60", "#006062", "#006165", "#006367", "#006367", "#006367", "#006367", "#006367",
    "#616161", "#4e6764", "#306b67", "#006f6b", "#00736e", "#007672", "#007875", "#007b78", "#007d7b", "#007e7d", "#008080", "#008182", "#008283", "#008283", "#008283",
    "#7a7a7a", "#66817e", "#4c8580", "#248983", "#008d86", "#00918a", "#00948d", "#00978f", "#009a93", "#009c96", "#009e98", "#00a09a", "#00a19c", "#00a29e", "#00a29e",
    "#949494", "#7f9b97", "#64a099", "#41a59c", "#00a99f", "#00aca1", "#00b0a4", "#00b3a7", "#00b6aa", "#00b8ac", "#00bbaf", "#00bdb2", "#00bfb4", "#00c1b6", "#00c1b6",
    "#aeaeae", "#98b6b1", "#7fbbb3", "#62c0b5", "#2cc4b7", "#00c8ba", "#00ccbc", "#00cfbe", "#00d2c1", "#00d5c4", "#00d8c6", "#00dbc9", "#00ddcc", "#00ddcc", "#00ddcc",
    "#c8c8c8", "#b2d1cb", "#98d7cc", "#7adcce", "#4de0d0", "#00e4d2", "#00e8d4", "#00ecd6", "#00efd8", "#00f3db", "#00f3db", "#00f3db", "#00f3db", "#00f3db", "#00f3db",
    "#e3e3e3", "#cbede6", "#aff3e7", "#8cf9e8", "#5cfeea", "#00ffec", "#00ffee", "#00ffee", "#00ffee", "#00ffee", "#00ffee", "#00ffee", "#00ffee", "#00ffee", "#00ffee",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5BG
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#0b2022", "#002429", "#00272f", "#002a37", "#002a37", "#002a37", "#002a37", "#002a37", "#002a37", "#002a37", "#002a37", "#002a37", "#002a37", "#002a37",
    "#313131", "#223536", "#00393c", "#003b41", "#003e47", "#00414b", "#00434f", "#004453", "#004453", "#004453", "#004453", "#004453", "#004453", "#004453", "#004453",
    "#484848", "#364d4e", "#0f5154", "#005459", "#00575e", "#005a63", "#005c67", "#005e6b", "#00606e", "#006272", "#006272", "#006272", "#006272", "#006272", "#006272",
    "#616161", "#4d6667", "#2f6b6c", "#006f71", "#007277", "#00757c", "#007881", "#007b86", "#007d8a", "#007e8d", "#008090", "#008193", "#008193", "#008193", "#008193",
    "#7a7a7a", "#668180", "#4c8585", "#1d8989", "#008d8f", "#009194", "#00949a", "#00969e", "#0099a3", "#009ca7", "#009eab", "#00a0ae", "#00a1b1", "#00a1b1", "#00a1b1",
    "#949494", "#7f9b9a", "#63a09e", "#3ea4a3", "#00a8a8", "#00acac", "#00afb1", "#00b2b5", "#00b5ba", "#00b8be", "#00bbc2", "#00bdc7", "#00c0ca", "#00c0ca", "#00c0ca",
    "#aeaeae", "#98b6b4", "#7ebbb8", "#60bfbc", "#25c3c0", "#00c8c5", "#00cbc9", "#00cfce", "#00d2d2", "#00d5d6", "#00d7da", "#00dadf", "#00dadf", "#00dadf", "#00dadf",
    "#c8c8c8", "#b2d1ce", "#98d6d2", "#76dbd7", "#47e0db", "#00e4df", "#00e8e3", "#00ebe7", "#00efeb", "#00f2f0", "#00f2f0", "#00f2f0", "#00f2f0", "#00f2f0", "#00f2f0",
    "#e3e3e3", "#ccedea", "#aef3ed", "#89f9f2", "#52fef6", "#00fffa", "#00fffe", "#00fffe", "#00fffe", "#00fffe", "#00fffe", "#00fffe", "#00fffe", "#00fffe", "#00fffe",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10BG (0B)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#0a2024", "#00232d", "#002635", "#00293e", "#00293e", "#00293e", "#00293e", "#00293e", "#00293e", "#00293e", "#00293e", "#00293e", "#00293e", "#00293e",
    "#313131", "#223538", "#003840", "#003b47", "#003e4f", "#004057", "#00425e", "#004463", "#004463", "#004463", "#004463", "#004463", "#004463", "#004463", "#004463",
    "#484848", "#354d50", "#0e5158", "#005460", "#005667", "#00596e", "#005c75", "#005e7b", "#006080", "#006183", "#006183", "#006183", "#006183", "#006183", "#006183",
    "#616161", "#4d6669", "#2f6a70", "#006e78", "#007180", "#007488", "#00778f", "#007a96", "#007c9b", "#007ea0", "#0080a5", "#0081a9", "#0081a9", "#0081a9", "#0081a9",
    "#7a7a7a", "#668082", "#4c8489", "#1c8891", "#008c99", "#008fa0", "#0093a8", "#0095ae", "#0098b5", "#009bbc", "#009ec2", "#00a0c6", "#00a1ca", "#00a1ca", "#00a1ca",
    "#949494", "#7f9b9c", "#659fa3", "#3ea3aa", "#00a7b1", "#00abb8", "#00aec0", "#00b1c6", "#00b4cd", "#00b7d4", "#00bada", "#00bde1", "#00c0e7", "#00c0e7", "#00c0e7",
    "#aeaeae", "#99b5b6", "#7fbabd", "#61bec3", "#21c2ca", "#00c6d2", "#00cad9", "#00cde0", "#00d1e7", "#00d4ed", "#00d7f2", "#00d9f9", "#00d9f9", "#00d9f9", "#00d9f9",
    "#c8c8c8", "#b3d0d0", "#98d6d7", "#77dade", "#44dfe4", "#00e3eb", "#00e7f2", "#00ebf8", "#00efff", "#00f2ff", "#00f2ff", "#00f2ff", "#00f2ff", "#00f2ff", "#00f2ff",
    "#e3e3e3", "#cdecec", "#aff2f3", "#89f8fa", "#51fdff", "#00ffff", "#00ffff", "#00ffff", "#00ffff", "#00ffff", "#00ffff", "#00ffff", "#00ffff", "#00ffff", "#00ffff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5B
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#0a2026", "#002330", "#002539", "#002844", "#002844", "#002844", "#002844", "#002844", "#002844", "#002844", "#002844", "#002844", "#002844", "#002844",
    "#313131", "#22353a", "#003843", "#003a4d", "#003d56", "#004060", "#004268", "#004268", "#004268", "#004268", "#004268", "#004268", "#004268", "#004268", "#004268",
    "#484848", "#364d52", "#10505c", "#005366", "#00566f", "#005878", "#005b81", "#005d89", "#005f8f", "#005f8f", "#005f8f", "#005f8f", "#005f8f", "#005f8f", "#005f8f",
    "#616161", "#4e666a", "#316a74", "#006d7e", "#007088", "#007392", "#00769b", "#0079a4", "#007baa", "#007db3", "#007db3", "#007db3", "#007db3", "#007db3", "#007db3",
    "#7a7a7a", "#688084", "#4e848d", "#228797", "#008ba0", "#008eaa", "#0091b4", "#0094bd", "#0097c6", "#009acf", "#009dd8", "#009dd8", "#009dd8", "#009dd8", "#009dd8",
    "#949494", "#819a9e", "#689ea7", "#42a2b1", "#00a6ba", "#00a9c3", "#00adcd", "#00b0d6", "#00b3e0", "#00b6e8", "#00b9f1", "#00b9f1", "#00b9f1", "#00b9f1", "#00b9f1",
    "#aeaeae", "#9bb5b8", "#81b9c1", "#63bdca", "#2bc1d3", "#00c5dd", "#00c9e7", "#00ccf0", "#00d0fb", "#00d2ff", "#00d2ff", "#00d2ff", "#00d2ff", "#00d2ff", "#00d2ff",
    "#c8c8c8", "#b6d0d2", "#9ad5db", "#79d9e4", "#47ddee", "#00e2f8", "#00e6ff", "#00e9ff", "#00edff", "#00edff", "#00edff", "#00edff", "#00edff", "#00edff", "#00edff",
    "#e3e3e3", "#d0ebee", "#b0f1f8", "#8af7ff", "#54fbff", "#54fbff", "#54fbff", "#54fbff", "#54fbff", "#54fbff", "#54fbff", "#54fbff", "#54fbff", "#54fbff", "#54fbff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5B
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#0b2027", "#002232", "#00243d", "#002648", "#002857", "#002857", "#002857", "#002857", "#002857", "#002857", "#002857", "#002857", "#002857", "#002857",
    "#313131", "#22353b", "#003746", "#003952", "#003c5e", "#003e69", "#004073", "#004073", "#004073", "#004073", "#004073", "#004073", "#004073", "#004073", "#004073",
    "#484848", "#364c54", "#164f60", "#00526b", "#005476", "#005682", "#00598d", "#005b98", "#005da1", "#005da1", "#005da1", "#005da1", "#005da1", "#005da1", "#005da1",
    "#616161", "#4f656c", "#366978", "#006b83", "#006e8f", "#00709b", "#0073a6", "#0076b2", "#0078be", "#007ac9", "#007ac9", "#007ac9", "#007ac9", "#007ac9", "#007ac9",
    "#7a7a7a", "#697f85", "#528390", "#2e869c", "#0088a8", "#008bb4", "#008ec0", "#0091cc", "#0094d9", "#0096e5", "#0099f0", "#0099f0", "#0099f0", "#0099f0", "#0099f0",
    "#949494", "#83999f", "#6c9daa", "#4ca1b6", "#00a4c2", "#00a6ce", "#00a9da", "#00ace6", "#00aff3", "#00b2ff", "#00b5ff", "#00b5ff", "#00b5ff", "#00b5ff", "#00b5ff",
    "#aeaeae", "#9eb4b9", "#86b8c5", "#69bcd0", "#3ebfdc", "#00c2e9", "#00c6f7", "#00c8ff", "#00ccff", "#00ccff", "#00ccff", "#00ccff", "#00ccff", "#00ccff", "#00ccff",
    "#c8c8c8", "#b9cfd4", "#9fd3e0", "#81d7ec", "#52dbf9", "#00dfff", "#00e3ff", "#00e3ff", "#00e3ff", "#00e3ff", "#00e3ff", "#00e3ff", "#00e3ff", "#00e3ff", "#00e3ff",
    "#e3e3e3", "#d3eaef", "#b5f0fd", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff", "#93f4ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5B
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#0d1f29", "#002134", "#00223f", "#00244b", "#002659", "#002659", "#002659", "#002659", "#002659", "#002659", "#002659", "#002659", "#002659", "#002659",
    "#313131", "#23343d", "#063649", "#003855", "#003a62", "#003c6e", "#003e78", "#004084", "#004084", "#004084", "#004084", "#004084", "#004084", "#004084", "#004084",
    "#484848", "#384c56", "#1e4e62", "#00506e", "#00527b", "#005487", "#005693", "#0058a0", "#005aaa", "#005aaa", "#005aaa", "#005aaa", "#005aaa", "#005aaa", "#005aaa",
    "#616161", "#52656d", "#3c677a", "#1a6986", "#006c93", "#006da0", "#0070ac", "#0072b9", "#0075c7", "#0076d1", "#0076d1", "#0076d1", "#0076d1", "#0076d1", "#0076d1",
    "#7a7a7a", "#6c7e87", "#588193", "#3c84a0", "#0086ac", "#0088b9", "#008bc7", "#008dd4", "#008fe2", "#0092f0", "#0094fb", "#0094fb", "#0094fb", "#0094fb", "#0094fb",
    "#949494", "#8699a0", "#729cac", "#589eba", "#30a1c7", "#00a3d4", "#00a6e2", "#00a8f0", "#00abff", "#00aeff", "#00b0ff", "#00b0ff", "#00b0ff", "#00b0ff", "#00b0ff",
    "#aeaeae", "#a0b3ba", "#8bb7c7", "#73bad3", "#50bce1", "#00bff0", "#00c2ff", "#00c5ff", "#00c5ff", "#00c5ff", "#00c5ff", "#00c5ff", "#00c5ff", "#00c5ff", "#00c5ff",
    "#c8c8c8", "#bcced4", "#a4d2e2", "#8ad5f0", "#62d9ff", "#00dcff", "#00dcff", "#00dcff", "#00dcff", "#00dcff", "#00dcff", "#00dcff", "#00dcff", "#00dcff", "#00dcff",
    "#e3e3e3", "#d6e9f0", "#baeeff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff", "#9af3ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10B (0PB)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#1d1d1d", "#0f1f2a", "#002035", "#002140", "#00224d", "#00245a", "#00245a", "#00245a", "#00245a", "#00245a", "#00245a", "#00245a", "#00245a", "#00245a",
    "#313131", "#26343e", "#10354b", "#003757", "#003865", "#003a71", "#003b7d", "#003c8a", "#003c8a", "#003c8a", "#003c8a", "#003c8a", "#003c8a", "#003c8a", "#003c8a",
    "#484848", "#3b4b57", "#274d64", "#004e71", "#00507d", "#00518a", "#005397", "#0055a4", "#0056af", "#0056af", "#0056af", "#0056af", "#0056af", "#0056af", "#0056af",
    "#616161", "#54646e", "#43667c", "#2b6888", "#006996", "#006ba2", "#006daf", "#006ebd", "#0070cb", "#0072d8", "#0072d8", "#0072d8", "#0072d8", "#0072d8", "#0072d8",
    "#7a7a7a", "#6e7e88", "#5e8095", "#4982a2", "#2584af", "#0085bd", "#0087cb", "#0089d8", "#008be7", "#008df4", "#008fff", "#008fff", "#008fff", "#008fff", "#008fff",
    "#949494", "#8998a1", "#799aae", "#649cbc", "#489eca", "#06a0d7", "#00a2e7", "#00a4f6", "#00a7ff", "#00a9ff", "#00abff", "#00abff", "#00abff", "#00abff", "#00abff",
    "#aeaeae", "#a3b2bb", "#92b5c8", "#7eb7d6", "#65b9e5", "#37bcf5", "#00beff", "#00c0ff", "#00c0ff", "#00c0ff", "#00c0ff", "#00c0ff", "#00c0ff", "#00c0ff", "#00c0ff",
    "#c8c8c8", "#becdd5", "#acd0e4", "#96d3f3", "#76d6ff", "#47d8ff", "#47d8ff", "#47d8ff", "#47d8ff", "#47d8ff", "#47d8ff", "#47d8ff", "#47d8ff", "#47d8ff", "#47d8ff",
    "#e3e3e3", "#d9e9f0", "#c1ecff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff", "#a6f0ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5PB
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#131e2b", "#011f36", "#001f42", "#001f4e", "#00205b", "#00205b", "#00205b", "#00205b", "#00205b", "#00205b", "#00205b", "#00205b", "#00205b", "#00205b",
    "#313131", "#28333f", "#1a344c", "#003459", "#003566", "#003673", "#003680", "#00378f", "#00378f", "#00378f", "#00378f", "#00378f", "#00378f", "#00378f", "#00378f",
    "#484848", "#3e4a58", "#304b65", "#194c72", "#004d7f", "#004d8c", "#004e9a", "#004fa7", "#0050b4", "#0050b4", "#0050b4", "#0050b4", "#0050b4", "#0050b4", "#0050b4",
    "#616161", "#58636f", "#4b647d", "#3b658a", "#1e6698", "#0067a4", "#0068b1", "#0069c0", "#0069ce", "#006adc", "#006adc", "#006adc", "#006adc", "#006adc", "#006adc",
    "#7a7a7a", "#727d88", "#657e96", "#567fa4", "#4280b1", "#1e81bf", "#0082cd", "#0083db", "#0084eb", "#0086fa", "#0087ff", "#0087ff", "#0087ff", "#0087ff", "#0087ff",
    "#949494", "#8c97a1", "#8098af", "#719abd", "#5f9bcc", "#469cda", "#009dea", "#009ffa", "#00a0ff", "#00a1ff", "#00a1ff", "#00a1ff", "#00a1ff", "#00a1ff", "#00a1ff",
    "#aeaeae", "#a7b1bb", "#9ab3ca", "#8bb4d8", "#79b6e7", "#5fb7f8", "#33b9ff", "#00baff", "#00baff", "#00baff", "#00baff", "#00baff", "#00baff", "#00baff", "#00baff",
    "#c8c8c8", "#c2ccd5", "#b4cee5", "#a2d0f5", "#8dd2ff", "#6fd4ff", "#6fd4ff", "#6fd4ff", "#6fd4ff", "#6fd4ff", "#6fd4ff", "#6fd4ff", "#6fd4ff", "#6fd4ff", "#6fd4ff",
    "#e3e3e3", "#dde7f0", "#cbeaff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff", "#b7ecff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5PB
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#161d2b", "#0c1d36", "#001d42", "#001c4e", "#001b5b", "#001967", "#001770", "#00147b", "#001183", "#000d8d", "#000895", "#00029e", "#0000a7", "#0000b0",
    "#313131", "#2c3240", "#22324c", "#12325a", "#003267", "#003174", "#003180", "#002f8e", "#002d9c", "#002ca8", "#002ab0", "#0028ba", "#0025c6", "#0023cf", "#0021d4",
    "#484848", "#414958", "#384966", "#2b4a73", "#164a80", "#004a8d", "#00499b", "#0049a8", "#0048b6", "#0047c4", "#0046d0", "#0044dc", "#0043ea", "#0041f3", "#003ffe",
    "#616161", "#5b6270", "#53627d", "#48638b", "#386399", "#2163a6", "#0063b2", "#0063c0", "#0063cf", "#0063de", "#0062ef", "#0061fd", "#005fff", "#005eff", "#005dff",
    "#7a7a7a", "#757c89", "#6d7c96", "#627da4", "#557db2", "#447dc0", "#277ece", "#007edc", "#007eec", "#007efc", "#007eff", "#007eff", "#007dff", "#007dff", "#007dff",
    "#949494", "#8f96a2", "#8797af", "#7c97bf", "#7197cd", "#6198db", "#4999eb", "#1a99fc", "#009aff", "#009aff", "#009aff", "#009aff", "#009aff", "#009aff", "#009aff",
    "#aeaeae", "#a9b0bb", "#a0b1ca", "#96b2d9", "#89b2e8", "#79b3f9", "#5fb4ff", "#3fb4ff", "#3fb4ff", "#3fb4ff", "#3fb4ff", "#3fb4ff", "#3fb4ff", "#3fb4ff", "#3fb4ff",
    "#c8c8c8", "#c4cbd5", "#bacce5", "#aecdf7", "#9eceff", "#8dceff", "#8dceff", "#8dceff", "#8dceff", "#8dceff", "#8dceff", "#8dceff", "#8dceff", "#8dceff", "#8dceff",
    "#e3e3e3", "#e0e7f0", "#d4e7ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff", "#c5e9ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5PB
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#1b1c2c", "#191a36", "#171841", "#17144c", "#190f54", "#1c075d", "#200065", "#25006e", "#280075", "#2c007d", "#300085", "#34008d", "#390097", "#3e00a1",
    "#313131", "#303140", "#2d304d", "#2a2e59", "#262c65", "#252970", "#25257a", "#271f84", "#2a188d", "#2d0b97", "#31009f", "#3500a9", "#3800b1", "#3c00b9", "#4000c1",
    "#484848", "#464859", "#424766", "#3f4573", "#3b447f", "#37428c", "#343f97", "#323ba4", "#3236b0", "#3431b9", "#362bc2", "#3921cd", "#3c12d7", "#3f00e0", "#4200e8",
    "#616161", "#5f6170", "#5c607d", "#585f8a", "#535e98", "#4e5ca5", "#495bb1", "#4458bd", "#4155ca", "#3f51d7", "#3e4ce5", "#3e47ef", "#3f41fa", "#4139ff", "#4231ff",
    "#7a7a7a", "#787b89", "#757a96", "#7079a4", "#6c78b2", "#6777be", "#6275cc", "#5b74da", "#5472e8", "#4e6ff7", "#496bff", "#4667ff", "#4361ff", "#3a5cff", "#3a5cff",
    "#949494", "#9395a2", "#8f94af", "#8a93be", "#8693cb", "#8192d9", "#7a90e9", "#728ff9", "#668dff", "#608bff", "#5888ff", "#5888ff", "#5888ff", "#5888ff", "#5888ff",
    "#aeaeae", "#adafbb", "#a8afca", "#a4aed9", "#9eade9", "#98acf9", "#91abff", "#89aaff", "#89aaff", "#89aaff", "#89aaff", "#89aaff", "#89aaff", "#89aaff", "#89aaff",
    "#c8c8c8", "#c8cad5", "#c2cae5", "#bcc9f6", "#b5c8ff", "#aec7ff", "#aec7ff", "#aec7ff", "#aec7ff", "#aec7ff", "#aec7ff", "#aec7ff", "#aec7ff", "#aec7ff", "#aec7ff",
    "#e3e3e3", "#e3e6f0", "#dde5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff", "#d6e5ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10PB (0P)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#1f1b2c", "#211835", "#23143f", "#260f47", "#29084f", "#2d0057", "#31005f", "#350067", "#39006e", "#3e0076", "#42007e", "#470086", "#4d0091", "#53009b",
    "#313131", "#333040", "#352d4b", "#362b55", "#382760", "#3b226a", "#3e1c73", "#41137c", "#450485", "#4a008e", "#4e0097", "#5300a0", "#5700a8", "#5c00b1", "#6100ba",
    "#484848", "#4a4758", "#4b4465", "#4c4271", "#4d3f7c", "#4f3b87", "#513791", "#54319c", "#582aa6", "#5c21af", "#6013b8", "#6400c1", "#6800cb", "#6c00d4", "#7100dd",
    "#616161", "#626070", "#635e7c", "#635c89", "#645995", "#6556a0", "#6653ac", "#684fb7", "#6b4ac2", "#6e45cc", "#713dd8", "#7436e0", "#782cea", "#7d1bf5", "#8000fe",
    "#7a7a7a", "#7c7a88", "#7c7895", "#7c76a3", "#7c74af", "#7d71bb", "#7d6ec7", "#7e6bd4", "#7f67e0", "#8163eb", "#845ef7", "#8757ff", "#8a50ff", "#8e45ff", "#8e45ff",
    "#949494", "#9594a1", "#9593ae", "#9591bc", "#958fc9", "#958cd6", "#958ae4", "#9586f2", "#9682ff", "#977fff", "#987aff", "#987aff", "#987aff", "#987aff", "#987aff",
    "#aeaeae", "#afafbb", "#afadc9", "#aeabd7", "#aea9e6", "#ada7f5", "#aea4ff", "#afa0ff", "#afa0ff", "#afa0ff", "#afa0ff", "#afa0ff", "#afa0ff", "#afa0ff", "#afa0ff",
    "#c8c8c8", "#cacad4", "#c9c8e4", "#c8c6f4", "#c8c3ff", "#c8c0ff", "#c8c0ff", "#c8c0ff", "#c8c0ff", "#c8c0ff", "#c8c0ff", "#c8c0ff", "#c8c0ff", "#c8c0ff", "#c8c0ff",
    "#e3e3e3", "#e6e5ef", "#e4e3ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff", "#e0e2ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5P
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#221a2b", "#261633", "#2a113b", "#2f0a43", "#33014a", "#380052", "#3c0059", "#410061", "#450067", "#4a006e", "#4f0076", "#55007e", "#5c0089", "#620092",
    "#313131", "#362f3f", "#3a2c49", "#3e2851", "#43235b", "#471c64", "#4c136d", "#510375", "#55007d", "#5b0085", "#60008e", "#650096", "#6b00a0", "#7100a9", "#7800b3",
    "#484848", "#4d4657", "#514263", "#553f6d", "#593b77", "#5e3581", "#632f8a", "#682794", "#6d1c9d", "#7108a5", "#7600ad", "#7c00b6", "#8100c0", "#8600c8", "#8c00d2",
    "#616161", "#655f6f", "#695c7b", "#6c5985", "#705690", "#74519a", "#794da4", "#7d47ae", "#8240b8", "#8738c1", "#8c2dcc", "#9121d3", "#9605dc", "#9b00e6", "#a000ef",
    "#7a7a7a", "#7e7987", "#817793", "#84749f", "#8870ab", "#8c6db5", "#9068c0", "#9564ca", "#995ed5", "#9e59de", "#a351e9", "#a848f4", "#ad3dfe", "#b32eff", "#b32eff",
    "#949494", "#9893a1", "#9b91ac", "#9e8eb9", "#a18bc5", "#a588d1", "#a984dc", "#ad7fe8", "#b379f4", "#b775fe", "#bd6dff", "#bd6dff", "#bd6dff", "#bd6dff", "#bd6dff",
    "#aeaeae", "#b2aeba", "#b5acc7", "#b7a9d4", "#bba6e1", "#bea2ee", "#c39efc", "#c899ff", "#c899ff", "#c899ff", "#c899ff", "#c899ff", "#c899ff", "#c899ff", "#c899ff",
    "#c8c8c8", "#ccc9d4", "#cfc6e2", "#d2c4f0", "#d5c0ff", "#dbbbff", "#dbbbff", "#dbbbff", "#dbbbff", "#dbbbff", "#dbbbff", "#dbbbff", "#dbbbff", "#dbbbff", "#dbbbff",
    "#e3e3e3", "#e7e4ef", "#eae2ff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff", "#eddeff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5P
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#25192a", "#2a1431", "#2f0f38", "#34063f", "#390046", "#3e004d", "#430054", "#49005b", "#4d0061", "#530068", "#590070", "#5e0076", "#660080", "#660080",
    "#313131", "#392e3e", "#3e2b46", "#43264e", "#492057", "#4f185f", "#540a67", "#5a006f", "#5f0076", "#65007e", "#6b0086", "#71008e", "#780097", "#7f00a0", "#8700aa",
    "#484848", "#504556", "#564160", "#5c3d69", "#623772", "#67317c", "#6e2984", "#731e8c", "#790b95", "#7e009d", "#8400a4", "#8a00ac", "#9100b5", "#9700bd", "#9e00c6",
    "#616161", "#685e6e", "#6e5b78", "#735782", "#78538b", "#7e4e94", "#84489d", "#8a41a6", "#9138b0", "#962db8", "#9c1cc1", "#a200c8", "#a800d1", "#ae00d9", "#b500e3",
    "#7a7a7a", "#817986", "#867591", "#8c719b", "#926da6", "#9769af", "#9d64b9", "#a35ec2", "#a958cb", "#af50d4", "#b547dd", "#bb3be7", "#c22af1", "#c80bf9", "#d000ff",
    "#949494", "#9a93a0", "#a090aa", "#a58cb5", "#ab88c0", "#b084ca", "#b67fd4", "#bd7adf", "#c374e9", "#c96df3", "#cf65fe", "#d858ff", "#df4cff", "#e738ff", "#f009ff",
    "#aeaeae", "#b4aeb9", "#b9aac5", "#bfa7d0", "#c4a3db", "#ca9fe7", "#d19af3", "#d795fd", "#de8eff", "#e588ff", "#ec7fff", "#f574ff", "#f574ff", "#f574ff", "#f574ff",
    "#c8c8c8", "#cec9d3", "#d3c5e0", "#d9c2ec", "#dfbdfa", "#e6b9ff", "#ecb4ff", "#f3aeff", "#f3aeff", "#f3aeff", "#f3aeff", "#f3aeff", "#f3aeff", "#f3aeff", "#f3aeff",
    "#e3e3e3", "#e9e4ee", "#eee0fe", "#f5dcff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff", "#fed7ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5P
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#261829", "#2c1330", "#310d36", "#37033d", "#3c0043", "#420049", "#480051", "#4d0057", "#52005d", "#580063", "#5e006a", "#630070", "#630070", "#630070",
    "#313131", "#3b2e3c", "#412944", "#47254b", "#4e1d53", "#55135b", "#5b0162", "#610069", "#670070", "#6d0077", "#73007e", "#7a0087", "#81008f", "#890097", "#9300a3",
    "#484848", "#534454", "#5b3f5d", "#623a65", "#69346d", "#702c75", "#77227d", "#7d1185", "#83008c", "#8a0094", "#90009a", "#9600a2", "#9e00aa", "#a400b1", "#ac00ba",
    "#616161", "#6b5d6c", "#735974", "#7a557c", "#815085", "#884a8c", "#8f4394", "#963a9d", "#9e2ea5", "#a51cad", "#ac00b5", "#b200bc", "#b800c3", "#c000cb", "#c700d3",
    "#7a7a7a", "#837883", "#8c748c", "#946f95", "#9c6a9e", "#a365a6", "#ab5eaf", "#b257b6", "#b94fbe", "#c145c7", "#c838cf", "#d022d8", "#d600df", "#de00e7", "#e500f0",
    "#949494", "#9e929d", "#a68ea5", "#ae89af", "#b685b7", "#be7fc0", "#c67ac8", "#ce73d1", "#d66cda", "#dd63e2", "#e657ec", "#ef49f6", "#f736fe", "#ff00ff", "#ff00ff",
    "#aeaeae", "#b7adb7", "#c0a9bf", "#c9a4c8", "#d19fd2", "#db9adb", "#e294e4", "#eb8ded", "#f486f6", "#fd7dff", "#ff73ff", "#ff66ff", "#ff56ff", "#ff3fff", "#ff3fff",
    "#c8c8c8", "#d1c8d0", "#dbc3da", "#e4bfe3", "#efb9ee", "#f8b3f7", "#ffadff", "#ffa6ff", "#ff9fff", "#ff9fff", "#ff9fff", "#ff9fff", "#ff9fff", "#ff9fff", "#ff9fff",
    "#e3e3e3", "#ece3eb", "#f8def6", "#ffd9ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff", "#ffd2ff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 10P (0RP)
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#281827", "#2e132e", "#340b34", "#3a013a", "#3f0040", "#450046", "#4b004d", "#510053", "#560058", "#5c005f", "#620065", "#69006c", "#69006c", "#69006c",
    "#313131", "#3d2d3b", "#442941", "#4b2347", "#531a4f", "#590e55", "#60005c", "#670063", "#6e006a", "#750070", "#7b0077", "#83007e", "#8b0087", "#93008f", "#a0009b",
    "#484848", "#554452", "#5e3e59", "#663960", "#6f3167", "#77286e", "#7f1976", "#86007c", "#8d0082", "#94008a", "#9b008f", "#a20096", "#a9009d", "#b000a4", "#ba00ad",
    "#616161", "#6d5d69", "#775870", "#805377", "#884d7e", "#904684", "#993d8b", "#a13392", "#a82598", "#b100a0", "#ba00a8", "#c000ad", "#c700b3", "#cf00ba", "#d700c1",
    "#7a7a7a", "#857782", "#907388", "#9a6d8f", "#a46797", "#ac619d", "#b559a4", "#be51ab", "#c647b1", "#ce3ab8", "#d726bf", "#df00c5", "#e600cc", "#f000d4", "#f700da",
    "#949494", "#a0929b", "#a98da2", "#b488a9", "#be82b0", "#c77cb7", "#d175bd", "#da6dc5", "#e365cb", "#eb5bd2", "#f54dda", "#fe3be1", "#ff1fe9", "#ff00f1", "#ff00f9",
    "#aeaeae", "#b9acb5", "#c4a8bc", "#cfa2c3", "#da9dca", "#e496d1", "#ee90d8", "#f889df", "#ff7fe7", "#ff75ef", "#ff69f6", "#ff59ff", "#ff46ff", "#ff28ff", "#ff28ff",
    "#c8c8c8", "#d2c8cf", "#dfc3d6", "#ebbddd", "#f7b7e5", "#ffb0ed", "#ffa9f4", "#ffa0fd", "#ff98ff", "#ff98ff", "#ff98ff", "#ff98ff", "#ff98ff", "#ff98ff", "#ff98ff",
    "#e3e3e3", "#eee3ea", "#fcddf2", "#ffd7f9", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff", "#ffcfff",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 2.5RP
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#291726", "#30122c", "#360a31", "#3d0037", "#43003d", "#480042", "#4f0048", "#55004e", "#5a0053", "#61005a", "#61005a", "#61005a", "#61005a", "#61005a",
    "#313131", "#3f2c38", "#47283d", "#4f2142", "#581748", "#5f054e", "#670053", "#6f0059", "#77005f", "#7e0065", "#85006a", "#8e0071", "#8e0071", "#8e0071", "#8e0071",
    "#484848", "#57434f", "#623d54", "#6c3759", "#752e5e", "#7e2264", "#870f69", "#8f006e", "#980073", "#a00079", "#a7007d", "#b00083", "#b80088", "#bf008d", "#bf008d",
    "#616161", "#6f5d67", "#7a576c", "#855171", "#8f4a75", "#98427a", "#a2387f", "#aa2b84", "#b31689", "#bc008e", "#c60094", "#ce0099", "#d6009e", "#dd00a3", "#e700a9",
    "#7a7a7a", "#87777f", "#937284", "#9f6c89", "#ab648e", "#b45e93", "#bf5598", "#c84b9d", "#d13ea1", "#da2da6", "#e30aab", "#ed00b1", "#f400b5", "#fd00ba", "#ff00c0",
    "#949494", "#a19199", "#ad8c9d", "#ba86a2", "#c480a6", "#cf7aab", "#da72b0", "#e569b5", "#ef5eba", "#f952bf", "#ff40c5", "#ff2ac9", "#ff00cf", "#ff00d4", "#ff00d9",
    "#aeaeae", "#bbacb3", "#c8a7b7", "#d5a1bc", "#e19ac0", "#ed94c5", "#f88cca", "#ff84cf", "#ff79d5", "#ff6cda", "#ff5ce0", "#ff4be6", "#ff38ea", "#ff38ea", "#ff38ea",
    "#c8c8c8", "#d4c7cd", "#e2c2d1", "#f1bbd5", "#ffb5da", "#ffaedf", "#ffa5e5", "#ff9bea", "#ff91f0", "#ff91f0", "#ff91f0", "#ff91f0", "#ff91f0", "#ff91f0", "#ff91f0",
    "#e3e3e3", "#efe3e8", "#ffdded", "#ffd6f1", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7", "#ffcef7",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 5RP
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2b1724", "#321129", "#39082e", "#400033", "#460037", "#4d003c", "#530041", "#590045", "#590045", "#590045", "#590045", "#590045", "#590045", "#590045",
    "#313131", "#402c36", "#49273a", "#52203d", "#5b1442", "#640046", "#6c004b", "#740050", "#7d0054", "#840058", "#8d005e", "#8d005e", "#8d005e", "#8d005e", "#8d005e",
    "#484848", "#59434c", "#653c4f", "#703552", "#7a2b55", "#841e59", "#8d045c", "#960061", "#9f0065", "#a70069", "#af006c", "#bb0073", "#bb0073", "#bb0073", "#bb0073",
    "#616161", "#715c64", "#7e5666", "#8a4f68", "#95476b", "#9f3f6d", "#a93370", "#b32373", "#bc0076", "#c6007a", "#d0007e", "#d80081", "#e20085", "#ec008a", "#ec008a",
    "#7a7a7a", "#89777d", "#97717e", "#a46a80", "#b16382", "#bc5b84", "#c85087", "#d24589", "#dc358c", "#e61d8f", "#f00091", "#f90094", "#ff0098", "#ff009b", "#ff009e",
    "#949494", "#a39196", "#b18c98", "#bf8599", "#cb7f9b", "#d6789d", "#e36f9f", "#ee64a2", "#f958a4", "#ff4aa7", "#ff30aa", "#ff07ac", "#ff00af", "#ff00b2", "#ff00b2",
    "#aeaeae", "#bcacb1", "#cba6b2", "#daa0b3", "#e899b5", "#f492b6", "#ff89b8", "#ff7fbb", "#ff73bd", "#ff65c0", "#ff57c3", "#ff43c5", "#ff43c5", "#ff43c5", "#ff43c5",
    "#c8c8c8", "#d5c7cb", "#e6c1cc", "#f6bacd", "#ffb3cf", "#ffabd0", "#ffa1d3", "#ff97d5", "#ff97d5", "#ff97d5", "#ff97d5", "#ff97d5", "#ff97d5", "#ff97d5", "#ff97d5",
    "#e3e3e3", "#f1e2e6", "#ffdce7", "#ffd4e8", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea", "#ffcdea",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff",
    // 7.5RP
    "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000", "#000000",
    "#1d1d1d", "#2c1722", "#341026", "#3b062a", "#42002e", "#4a0032", "#510036", "#57003a", "#5e003d", "#5e003d", "#5e003d", "#5e003d", "#5e003d", "#5e003d", "#5e003d",
    "#313131", "#412c34", "#4b2637", "#541f39", "#5e133c", "#67003f", "#700043", "#780047", "#80004a", "#89004e", "#89004e", "#89004e", "#89004e", "#89004e", "#89004e",
    "#484848", "#5a4349", "#673c4a", "#73344b", "#7e2a4d", "#881b4e", "#920050", "#9c0053", "#a50055", "#ae0058", "#b7005b", "#b7005b", "#b7005b", "#b7005b", "#b7005b",
    "#616161", "#725c61", "#805661", "#8d4f61", "#994662", "#a33d62", "#ae3064", "#b81d65", "#c20067", "#cc0069", "#d7006b", "#df006d", "#e90070", "#e90070", "#e90070",
    "#7a7a7a", "#8a777b", "#99717a", "#a76a7a", "#b5627a", "#c0597a", "#cc4e7a", "#d6427b", "#e1317c", "#eb127d", "#f6007f", "#ff0080", "#ff0082", "#ff0084", "#ff0085",
    "#949494", "#a49195", "#b38b94", "#c28493", "#ce7e92", "#db7692", "#e76d92", "#f36293", "#ff5494", "#ff4595", "#ff2996", "#ff0097", "#ff0098", "#ff0098", "#ff0098",
    "#aeaeae", "#bdacaf", "#cda6ae", "#dd9fad", "#eb98ac", "#f891ac", "#ff87ac", "#ff7cac", "#ff70ac", "#ff61ae", "#ff51ae", "#ff51ae", "#ff51ae", "#ff51ae", "#ff51ae",
    "#c8c8c8", "#d6c7ca", "#e8c1c8", "#f9bac7", "#ffb2c6", "#ffaac5", "#ff9fc5", "#ff95c5", "#ff95c5", "#ff95c5", "#ff95c5", "#ff95c5", "#ff95c5", "#ff95c5", "#ff95c5",
    "#e3e3e3", "#f2e2e5", "#ffdbe3", "#ffd4e1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1", "#ffcde1",
    "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff", "#ffffff"
];

